@@ -10,12 +10,12 @@ use Carp;
 use Mail::RFC822::Address;
 use DateTime;
 use DateTime::Format::DateParse;
-use Mojo::JSON                      qw(from_json);
+use Mojo::JSON;
 use List::MoreUtils                 qw(any firstval);
 
 use Mojolicious::Plugin::Vparam::Address;
 
-our $VERSION = '1.3';
+our $VERSION = '1.4';
 
 =encoding utf-8
 
@@ -478,7 +478,28 @@ sub _check_time($) {
 
 Get full date and time. Parsed from many formats.
 See I<datetime> configuration parameter for result format.
-See L<DateTime::Format::DateParse> and even more.
+
+Input formats:
+
+=over
+
+=item *
+
+Timestamp.
+
+=item *
+
+Relative in minutes. For example: +15 or -6 from now.
+
+=item *
+
+All that can be obtained L<DateTime::Format::DateParse>.
+
+=item *
+
+Russian date format like C<DD.MM.YYYY>
+
+=back
 
 =cut
 
@@ -497,6 +518,22 @@ You need always set default value to supress error if checkbox not checked:
 
     $self->vparam(mybox => 'bool', default => 0);
 
+Valid values are:
+
+=over
+
+=item
+
+I<TRUE> can be 1, yes, true, ok
+
+=item
+
+I<FALSE> can be 0, no, false, fail
+
+=back
+
+Other values get error.
+
 =cut
 
 sub _check_bool($) {
@@ -945,16 +982,17 @@ sub _parse_date($;$) {
     my $dt;
 
     if( $str =~ m{^\d+$} ) {
-        $dt = DateTime->from_epoch( epoch => int $str );
+        $dt = DateTime->from_epoch( epoch => int $str, time_zone => 'local' );
     } elsif( $str =~ m{^[\+\-]\d+$} ) {
         my $minutes = int $str;
-        $dt = DateTime->now();
+        $dt = DateTime->now(time_zone => 'local');
         $dt->add(minutes => $minutes);
     } else {
         # RU format
         $str =~ s{^(\d{1,2})\.(\d{1,2})\.(\d{4})(.*)$}{$3-$2-$1$4};
         # If looks like time add it
-        $str = DateTime->now->strftime('%F ') . $str if $str =~ m{^\s*\d{2}:};
+        $str = DateTime->now(time_zone => 'local')->strftime('%F ') . $str
+            if $str =~ m{^\s*\d{2}:};
 
         $dt = eval { DateTime::Format::DateParse->parse_datetime( $str ); };
         return undef if !$dt;
@@ -981,7 +1019,15 @@ sub _parse_json($) {
     return undef unless defined $str;
     return undef unless length  $str;
 
-    my $data = eval{ from_json $str };
+
+
+    my $data = eval{
+        if( version->new($Mojolicious::VERSION) < version->new(5.54) ) {
+            return Mojo::JSON->new->decode( $str );
+        } else {
+            return Mojo::JSON::decode_json( $str );
+        }
+    };
     warn $@ and return undef if $@;
 
     return $data;
@@ -1029,9 +1075,9 @@ sub register {
     $conf->{phone_country}  //= '';
     $conf->{phone_region}   //= '';
 
-    $conf->{date}           //= '%F';
-    $conf->{time}           //= '%T';
-    $conf->{datetime}       //= '%F %T %z';
+    $conf->{date}           = '%F'          unless exists $conf->{date};
+    $conf->{time}           = '%T'          unless exists $conf->{time};
+    $conf->{datetime}       = '%F %T %z'    unless exists $conf->{datetime};
 
     $conf->{optional}       //= 0;
 
@@ -1275,11 +1321,11 @@ sub register {
             if( 'HASH' eq ref $def ) {
                 %attr           = %$def;
             } elsif( 'Regexp' eq ref $def ) {
-                $attr{valid}    = sub { _like( $_[1], $def ) };
+                $attr{regexp}   = $def;
             } elsif( 'CODE' eq ref $def ) {
                 $attr{post}     = $def;
             } elsif( 'ARRAY' eq ref $def ) {
-                $attr{valid}    = sub { _in( $_[1], $def ) };
+                $attr{in}       = $def;
             } elsif( !ref $def ) {
                 $attr{type}     = $def;
             }
@@ -1445,8 +1491,7 @@ sub register {
         } elsif('CODE' eq ref $def) {
             $result = $self->vparams( $name => { post   => $def, %attr } );
         } elsif('ARRAY' eq ref $def) {
-            $def    = sub { _in( $_[1], $def ) };
-            $result = $self->vparams( $name => { valid  => $def, %attr } );
+            $result = $self->vparams( $name => { in     => $def, %attr } );
         } else {
             $result = $self->vparams( $name => { type   => $def, %attr } );
         }
